@@ -15,12 +15,9 @@ Test to add:
 - Read with missing pid
 """
 
-import time
-
 import pytest
-from invenio_pidstore.errors import PIDDeletedError, PIDUnregistered
+from invenio_pidstore.errors import PIDDoesNotExistError, PIDUnregistered
 from invenio_pidstore.models import PIDStatus
-from invenio_search import current_search, current_search_client
 from marshmallow.exceptions import ValidationError
 from sqlalchemy.orm.exc import NoResultFound
 
@@ -110,7 +107,7 @@ def test_update_draft_invalid_field(app, service, identity_simple, input_data):
     updated_draft_dict = updated_draft.to_dict()
 
     assert draft.id == updated_draft.id
-    assert updated_draft["metadata"]['title'] == orig_title
+    assert 'title' not in updated_draft["metadata"]
     assert updated_draft_dict['errors'][0]['field'] == 'metadata.title'
 
 
@@ -123,7 +120,7 @@ def test_delete_draft(app, service, identity_simple, input_data):
     assert success
 
     # Check draft deletion
-    with pytest.raises(NoResultFound):
+    with pytest.raises(PIDDoesNotExistError):
         # NOTE: Draft and Record have the same `id`
         delete_draft = service.read_draft(draft.id, identity_simple)
 
@@ -272,6 +269,7 @@ def test_mutiple_edit(app, service, identity_simple, input_data):
     assert draft._record.revision_id == 7  # soft-delete, undelete, update
 
 
+@pytest.mark.skip()  # Disable until properly implemented.
 def test_create_publish_new_version(app, service, identity_simple,
                                     input_data):
     """Test creating a new revision of a record.
